==> messagelib-23.03.90-1-x86_64.pkg.tar.zst: usr/lib/cmake/KPim5MessageViewer/KPim5MessageViewerConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimMessageViewerConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim5MessageViewer" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################
include(CMakeFindDependencyMacro)
find_dependency(KF5PimCommon "5.22.90")
find_dependency(KPim5MessageCore "5.22.90")
find_dependency(KPim5MimeTreeParser "5.22.90")
find_dependency(KPim5WebEngineViewer "5.22.90")
find_dependency(KPim5Akonadi "5.22.90")
find_dependency(KPim5Mime "5.22.90")
find_dependency(KF5Contacts "5.103.0")
find_dependency(KPim5Libkleo "5.22.90")
find_dependency(KF5Service "5.103.0")

include("${CMAKE_CURRENT_LIST_DIR}/KPim5MessageViewerTargets.cmake")

==> messagelib-23.08.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/KPim5MessageViewer/KPim5MessageViewerConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimMessageViewerConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim5MessageViewer" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################
include(CMakeFindDependencyMacro)
find_dependency(KPim5PimCommon "5.24.1")
find_dependency(KPim5MessageCore "5.24.1")
find_dependency(KPim5MimeTreeParser "5.24.1")
find_dependency(KPim5WebEngineViewer "5.24.1")
find_dependency(KPim5Akonadi "5.24.1")
find_dependency(KPim5Mime "5.24.1")
find_dependency(KF5Contacts "5.105.0")
find_dependency(KPim5Libkleo "5.24.1")
find_dependency(KF5Service "5.105.0")

include("${CMAKE_CURRENT_LIST_DIR}/KPim5MessageViewerTargets.cmake")
